.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _canary_gitlab.reporter:

reporter
========

.. automodule:: canary_gitlab.reporter
   :members:
   :undoc-members:
   :show-inheritance:
